@@ -1,18 +1,21 @@
 """Test workspace freezing functionality for tmuxp."""
+
 import contextlib
 import io
 import pathlib
 import typing as t
 
 import pytest
-from libtmux.server import Server
 
 from tmuxp import cli
 from tmuxp._internal.config_reader import ConfigReader
 
+if t.TYPE_CHECKING:
+    from libtmux.server import Server
+
 
 @pytest.mark.parametrize(
-    "cli_args,inputs",
+    ("cli_args", "inputs"),
     [
         (["freeze", "myfrozensession"], ["y\n", "./la.yaml\n", "y\n"]),
         (  # Exists
@@ -66,7 +69,7 @@ def test_freeze(
 
 
 @pytest.mark.parametrize(
-    "cli_args,inputs",
+    ("cli_args", "inputs"),
     [
         (  # Overwrite
             ["freeze", "mysession", "--force"],
