@@ -1,8 +1,9 @@
 """Utility functions for tmuxp fixtures."""
+
 import pathlib
 import typing as t
 
-from ..constants import FIXTURE_PATH
+from tests.constants import FIXTURE_PATH
 
 
 def get_workspace_file(
