@@ -1,19 +1,20 @@
 """Pytest configuration for tmuxp workspace tests."""
+
 import types
 
 import pytest
 
-from ..fixtures.structures import WorkspaceTestData
+from tests.fixtures.structures import WorkspaceTestData
 
 
-@pytest.fixture
+@pytest.fixture()
 def config_fixture() -> WorkspaceTestData:
     """Deferred import of tmuxp.tests.fixtures.*.
 
     pytest setup (conftest.py) patches os.environ["HOME"], delay execution of
     os.path.expanduser until here.
     """
-    from ..fixtures import workspace as test_workspace_data
+    from tests.fixtures import workspace as test_workspace_data
 
     return WorkspaceTestData(
         **{
